@@ -15,11 +15,13 @@ import Yesod.Default.Config --(fromArgs)
 -- import Yesod.Default.Main   (defaultMain)
 import Settings            --  (parseExtra)
 import Application          (makeApplication)
-import Data.Conduit.Network (HostPreference(HostIPv4))
+import Data.String
+import Data.Conduit.Network
 import Network.Wai.Handler.Warp (runSettings, defaultSettings, settingsPort)
 import Network.Wai.Handler.Launch (runUrlPort)
 --
 import Prelude hiding (putStrLn)
+import Control.Applicative ((<$>))
 import Control.Monad (when)
 import Data.Text (pack)
 import System.Exit (exitSuccess)
@@ -59,12 +61,13 @@ web opts j = do
   let j' = filterJournalTransactions (queryFromOpts d $ reportopts_ $ cliopts_ opts) j
       p = port_ opts
       u = base_url_ opts
+      staticRoot = pack <$> static_root_ opts
   _ <- printf "Starting web app on port %d with base url %s\n" p u
   app <- makeApplication opts j' AppConfig{appEnv = Development
                                           ,appPort = p
                                           ,appRoot = pack u
-                                          ,appHost = HostIPv4
-                                          ,appExtra = Extra "" Nothing
+                                          ,appHost = fromString "*4"
+                                          ,appExtra = Extra "" Nothing staticRoot
                                           }
   if server_ opts
    then do
