@@ -1,6 +1,7 @@
 module Hledger.Web.Options
 where
 import Prelude
+import Control.Applicative ((<$>))
 import Data.Maybe
 import System.Console.CmdArgs
 import System.Console.CmdArgs.Explicit
@@ -23,9 +24,10 @@ defbaseurlexample = (reverse $ drop 4 $ reverse $ defbaseurl defport) ++ "PORT"
 
 webflags :: [Flag [([Char], [Char])]]
 webflags = [
-  flagNone ["server"]  (setboolopt "server") ("log requests, don't auto-exit")
- ,flagReq ["base-url"]  (\s opts -> Right $ setopt "base-url" s opts) "URL" ("set the base url (default: "++defbaseurlexample++")")
- ,flagReq ["port"]  (\s opts -> Right $ setopt "port" s opts) "PORT" ("listen on this tcp port (default: "++show defport++")")
+  flagNone ["server"]   (setboolopt "server") ("log requests, and don't browse or auto-exit")
+ ,flagReq  ["port"]     (\s opts -> Right $ setopt "port" s opts) "PORT" ("set the tcp port (default: "++show defport++")")
+ ,flagReq  ["base-url"] (\s opts -> Right $ setopt "base-url" s opts) "BASEURL" ("set the base url (default: "++defbaseurlexample++")")
+ ,flagReq  ["file-url"] (\s opts -> Right $ setopt "file-url" s opts) "FILEURL" ("set the static files url (default: BASEURL/static)")
  ]
  
 webmode :: Mode [([Char], [Char])]
@@ -47,6 +49,7 @@ data WebOpts = WebOpts {
      server_   :: Bool
     ,base_url_ :: String
     ,port_     :: Int
+    ,static_root_ :: Maybe String
     ,cliopts_  :: CliOpts
  } deriving (Show)
 
@@ -56,6 +59,7 @@ defwebopts = WebOpts
     def
     def
     def
+    def
 
 -- instance Default WebOpts where def = defwebopts
 
@@ -67,6 +71,7 @@ toWebOpts rawopts = do
               port_ = p
              ,server_ = boolopt "server" rawopts
              ,base_url_ = maybe (defbaseurl p) stripTrailingSlash $ maybestringopt "base-url" rawopts
+             ,static_root_ = stripTrailingSlash <$> maybestringopt "static-root" rawopts
              ,cliopts_   = cliopts
              }
   where
